==> pyThunderbird-0.0.2.tar.gz: pyThunderbird-0.0.2/README.md <==
# pyThunderbird
python based access to Thunderbird mail

[![Documentation Status](https://readthedocs.org/projects/pyThunderbird/badge/?version=latest)](https://pyThunderbird.readthedocs.io/en/latest/?badge=latest)
[![pypi](https://img.shields.io/pypi/pyversions/pyThunderbird)](https://pypi.org/project/pyThunderbird/)
[![Github Actions Build](https://github.com/WolfgangFahl/pyThunderbird/workflows/Build/badge.svg?branch=master)](https://github.com/WolfgangFahl/pyThunderbird/actions?query=workflow%3ABuild+branch%3Amaster)
[![PyPI Status](https://img.shields.io/pypi/v/pyThunderbird.svg)](https://pypi.python.org/pypi/pyThunderbird/)
[![Downloads](https://pepy.tech/badge/pyThunderbird)](https://pepy.tech/project/pyThunderbird)
[![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/pyThunderbird.svg)](https://github.com/WolfgangFahl/pyThunderbird/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed/WolfgangFahl/pyThunderbird.svg)](https://github.com/WolfgangFahl/pyThunderbird/issues/?q=is%3Aissue+is%3Aclosed)
[![License](https://img.shields.io/github/license/WolfgangFahl/pyThunderbird.svg)](https://www.apache.org/licenses/LICENSE-2.0)

Installation
============
```bash
pip install pyThunderbird
```

Get Sources 
===========
```bash
git clone https://github.com/WolfgangFahl/pyThunderbird
cd pyThunderbird
scripts/install
```

Testing
=======
```bash
scripts/test
```

## Documentation
[Wiki](http://wiki.bitplan.com/index.php/PyThunderbird)

### Authors
* [Wolfgang Fahl](http://www.bitplan.com/Wolfgang_Fahl)

==> pyThunderbird-0.0.7.tar.gz: pyThunderbird-0.0.7/README.md <==
# pyThunderbird
python based access to Thunderbird mail

[![Documentation Status](https://readthedocs.org/projects/pyThunderbird/badge/?version=latest)](https://pyThunderbird.readthedocs.io/en/latest/?badge=latest)
[![pypi](https://img.shields.io/pypi/pyversions/pyThunderbird)](https://pypi.org/project/pyThunderbird/)
[![Github Actions Build](https://github.com/WolfgangFahl/pyThunderbird/workflows/Build/badge.svg?branch=main)](https://github.com/WolfgangFahl/pyThunderbird/actions?query=workflow%3ABuild+branch%3Amaster)
[![PyPI Status](https://img.shields.io/pypi/v/pyThunderbird.svg)](https://pypi.python.org/pypi/pyThunderbird/)
[![Downloads](https://pepy.tech/badge/pyThunderbird)](https://pepy.tech/project/pyThunderbird)
[![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/pyThunderbird.svg)](https://github.com/WolfgangFahl/pyThunderbird/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed/WolfgangFahl/pyThunderbird.svg)](https://github.com/WolfgangFahl/pyThunderbird/issues/?q=is%3Aissue+is%3Aclosed)
[![License](https://img.shields.io/github/license/WolfgangFahl/pyThunderbird.svg)](https://www.apache.org/licenses/LICENSE-2.0)

Installation
============
```bash
pip install pyThunderbird
```

Get Sources 
===========
```bash
git clone https://github.com/WolfgangFahl/pyThunderbird
cd pyThunderbird
scripts/install
```

Testing
=======
```bash
scripts/test
```

## Documentation
[Wiki](http://wiki.bitplan.com/index.php/PyThunderbird)

### Authors
* [Wolfgang Fahl](http://www.bitplan.com/Wolfgang_Fahl)
